(function(){

    const messageHtml = `
<div style="position: absolute; top: 5px; right: 10px; width: 20em; height: 1em; padding: 1em; background: #fff; border: 1px solid #aaa; box-shadow: 1px 1px 3px 3px rgba(0, 0, 0, 0.4); font-family: sans-serif; " class="him-notification-msg">
Incognito Browsing Data cleared.
</div>
`;

    showTemporaryMessage(messageHtml, 500, 800);

    /**
     * Will show a message, and then fade itself out, and then the dom nodes are fully removed from the page.
     */
    function showTemporaryMessage(messageHtml, timeToDisplayMillis, fadeoutDurationMillis) {
        // First, we add the message to the dom.
        // It will immediately display.
        const messageElem = htmlToElements(messageHtml);
        document.body.appendChild(messageElem);

        // We wait a tiny bit, and then change the opacity.
        // This will make it start to fade out.
        setTimeout(() => {
            messageElem.style.transition = `opacity ${fadeoutDurationMillis}ms ease`;
            messageElem.style.opacity = "0";
        }, timeToDisplayMillis);

        // Wait a little longer, and then remove the element from the dom.
        setTimeout(() => {
            messageElem.parentNode.removeChild(messageElem);
        }, timeToDisplayMillis + fadeoutDurationMillis + 1000);

    }



    /**
     * Recursively creates dom elements from your html string.
     *
     * @param {string} htmlStr
     * @return {DocumentFragment}
     */
    function htmlToFragment(htmlStr) {
        const template = document.createElement('template');
        template.innerHTML = htmlStr;
        return template.content;
    }

    /**
     * Recursively creates dom elements from your html string. Only the first top-level element will be returned.
     *
     * @example htmlToElements('  <label>foo <input value=123></label>').querySelector('input').value === '123'
     * @param {string} htmlStr
     * @return {Element}
     */
    function htmlToElements(htmlStr) {
        return htmlToFragment(htmlStr).firstElementChild;
    }

})();